==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/chimesdkmediapipelines/kotlin/outputs/MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property issueDetectionConfiguration Configuration for an issue detection rule.
 * @property keywordMatchConfiguration Configuration for a keyword match rule.
 * @property sentimentConfiguration Configuration for a sentiment rule.
 * @property type Element type.
 */
public data class MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule(
    public val issueDetectionConfiguration:
    MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleIssueDetectionConfiguration? =
        null,
    public val keywordMatchConfiguration:
    MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleKeywordMatchConfiguration? =
        null,
    public val sentimentConfiguration:
    MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleSentimentConfiguration? =
        null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.chimesdkmediapipelines.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule):
            MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule =
            MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule(
                issueDetectionConfiguration = javaType.issueDetectionConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleIssueDetectionConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                keywordMatchConfiguration = javaType.keywordMatchConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleKeywordMatchConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sentimentConfiguration = javaType.sentimentConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleSentimentConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                type = javaType.type(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/chimesdkmediapipelines/kotlin/outputs/MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property issueDetectionConfiguration Configuration for an issue detection rule.
 * @property keywordMatchConfiguration Configuration for a keyword match rule.
 * @property sentimentConfiguration Configuration for a sentiment rule.
 * @property type Rule type.
 */
public data class MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule(
    public val issueDetectionConfiguration: MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleIssueDetectionConfiguration? =
        null,
    public val keywordMatchConfiguration: MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleKeywordMatchConfiguration? =
        null,
    public val sentimentConfiguration: MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleSentimentConfiguration? =
        null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.chimesdkmediapipelines.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule): MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule =
            MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRule(
                issueDetectionConfiguration = javaType.issueDetectionConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleIssueDetectionConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                keywordMatchConfiguration = javaType.keywordMatchConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleKeywordMatchConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sentimentConfiguration = javaType.sentimentConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.chimesdkmediapipelines.kotlin.outputs.MediaInsightsPipelineConfigurationRealTimeAlertConfigurationRuleSentimentConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                type = javaType.type(),
            )
    }
}
